<h1 align="center"> <ins>PROJECT</ins> : Development of an interactive brain connectivity data mining tool </H1>


<p align="justify"> This project has been realized during a 4th year internship in order to develop a python software helping the brain connectivity research. </p>

<p align="justify"> To install and execute this software, you can use PyPI or Github method. (Either way, verify that python is already being present in the PATH.) </p>

<h2> INSTALL AND EXECUTION WITH PyPI : </h2>

1) Run <code> pip install -i https&#65279;://test.pypi.org/simple/ IACOB </code>
2) Run <code> pip install -r requirements.txt </code>
3) Run <code> iacob-app </code>

<h2> INSTALL AND EXECUTION WITH GitHub Download : </h2>

1) Run <code> git clone https&#65279;://scm.univ-tours.fr/projetspublics/lifat/iacob.git IACOB_APP && cd IACOB_APP </code>
2) Run <code> pip install -r requirements.txt </code>
3) Run (Windows) <code> python -m src.IACOB </code>
3) Run (Unix/MacOS) <code> python3 -m src.IACOB </code>


précison python doit être installé ?
# <ins>Authors</ins> :

- <ins>Developers</ins> :

    * Thibaud SCRIBE (thibaud.scribe@etu.univ-tours.fr)
    * Enzo CREUZET (enzo.creuzet@etu.univ-tours.fr)

- <ins>Supervisors</ins> :

    * Barthelemy SERRES (barthelemy.serres@univ-tours.fr)
    * Frederic ANDERSSON (frederic.andersson@univ-tours.fr)


